@@ -5,6 +5,8 @@ class AzureAPI(BaseMicrosoftAPI):
        super().__init__(tenant_ID, app_ID, secret_key,
                         'https://management.core.windows.net/.default')
        self.subscriptions = None
+       self.resource_groups = None
+       self.servers = None
 
     def list_subscriptions(self):
         url = 'https://management.azure.com/'\
@@ -38,7 +40,6 @@ class AzureAPI(BaseMicrosoftAPI):
                 self.subscriptions = self.subscriptionIds()
             subscriptions = self.subscriptions
 #            subscriptions = self.subscriptionIds()
-
         resource_groups = []
         for subscription in subscriptions:
             url = f'https://management.azure.com/subscriptions/{subscription}/'\
@@ -46,6 +47,10 @@ class AzureAPI(BaseMicrosoftAPI):
             resource_groups += self.call_api(url)
         return resource_groups
 
+    def resource_groups_id(self,subscriptions):
+        resource_groups = self.list_resource_groups(subscriptions)
+        return [item['id'] for item in resource_groups]
+
     def list_virtual_machines(self, subscriptions=None, status=False):
         if subscriptions is None:
             if self.subscriptions is None:
@@ -170,3 +175,65 @@ class AzureAPI(BaseMicrosoftAPI):
                   f'factories?api-version=2018-06-01'
             factories += self.call_api(url)
         return factories
+
+    def list_mssql_server(self, resource_groups=None):
+
+        if self.subscriptions is None:
+            self.subscriptions = self.subscriptionIds()
+        subscriptions = self.subscriptions
+
+        if resource_groups is None:
+            if self.resource_groups is None:
+                self.resource_groups = self.resource_groups_id(subscriptions)
+            resource_groups = self.resource_groups
+
+        subs = []
+        rgs = []
+        for row in resource_groups:
+            splited = row.split('/')
+            subs.append(splited[2].lower())
+            rgs.append(splited[4].lower())
+
+        servers = []
+        for i in range(len(subs)):
+                url = f'https://management.azure.com/subscriptions/{subs[i]}'\
+                    f'/resourceGroups/{rgs[i]}/providers/Microsoft.Sql/'\
+                    f'servers?api-version=2021-11-01-preview'
+                servers += self.call_api(url)
+        return servers
+
+    def servers_ids(self,resource_groups):
+        servers = self.list_mssql_server(resource_groups)
+        return [item['id'] for item in servers]
+
+    def list_mssql_database(self, servers=None):
+
+        if self.subscriptions is None:
+            self.subscriptions = self.subscriptionIds()
+        subscriptions = self.subscriptions
+
+        if self.resource_groups is None:
+            self.resource_groups = self.resource_groups_id(subscriptions)
+        resource_groups = self.resource_groups
+
+        if servers is None:
+            if self.servers is None:
+                self.servers = self.servers_ids(resource_groups)
+            servers = self.servers        
+
+        subs = []
+        rgs = []
+        server_names = []
+        for row in servers:
+            splited = row.split('/')
+            subs.append(splited[2].lower())
+            rgs.append(splited[4].lower())
+            server_names.append(splited[8].lower())
+
+        databases = []
+        for i in range(len(server_names)):
+                    url = f'https://management.azure.com/subscriptions/{subs[i]}'\
+                        f'/resourceGroups/{rgs[i]}/providers/Microsoft.Sql/servers/{server_names[i]}/'\
+                        f'databases?api-version=2021-11-01-preview'
+                    databases += self.call_api(url)
+        return databases
\ No newline at end of file
