@@ -5,9 +5,9 @@ import pathlib
 
 class BaseMicrosoftAPI:
     def __init__(self, tenant_ID, app_ID, secret_key, scope):
-        self.tenant_ID = tenant_ID
-        self.app_ID = app_ID
-        self.secret_key = secret_key
+        self.tenant_ID = tenant_ID.rstrip()
+        self.app_ID = app_ID.rstrip()
+        self.secret_key = secret_key.rstrip()
         self.scope = scope
         self.headers = self.get_auth()
 
@@ -18,14 +18,16 @@ class BaseMicrosoftAPI:
             'grant_type': 'client_credentials',
             'client_id': self.app_ID,
             'client_secret': self.secret_key,
-#            'scope': 'https://management.core.windows.net/.default',
-#            'scope': 'https://graph.microsoft.com/.default',
             'scope': self.scope,
         }
-        token = requests.post(token_url, data=auth)
-        token = token.json().get('access_token')
-        headers = {'Authorization': f'Bearer {token}'}
-        return headers
+        response = requests.post(token_url, data=auth)
+        token = response.json().get('access_token')
+        if token != None:
+            headers = {'Authorization': f'Bearer {token}'}
+            return headers
+        else:
+            raise Exception(f' BaseMicrosoftAPI authentication failed.\n'\
+                            f'Response: {response}')
 
     def call_api_stream(self, url):
         response = requests.get(url, headers=self.headers)
